# ChrootMan - Chroot Manager

✨ Manage chroots in a breeze! 

## Features

🚀 mount, unmount file system, and execute commands in one go

🔥 Fully configurable through `yaml` configuration file

## Examples

[![asciicast](https://asciinema.org/a/FdD1pQQ3XlXO5TnafexJe1C8p.svg)](https://asciinema.org/a/FdD1pQQ3XlXO5TnafexJe1C8p)

## Installing

```bash
pip install ChrootMan
chrootman -h
```
